@@ -37,7 +37,7 @@
 int
 main(int argc, char* argv[])
 {
-  Glib::ustring filepath;
+  std::string filepath;
   if(argc > 1 )
     filepath = argv[1]; //Allow the user to specify a different XML file to parse.
   else
